----------
Motivation
----------

Django is a very popular tool which provides data representation and management. One of the key goals is to provide
machine access to it. Most popular production ready tools provide json based api access. Which have their own
advantages and disadvantages.

WebDav today is a standard for cooperative document management. Its clients are built in the modern operation systems
and supported by the world popular services. But it very important to remember that it's not only about file storage,
WebDab provides a set of methods to deal with tree structured objects of any kind.

Providing WebDav access to Django resources opens new horizons for building Web2.0 apps, with inplace edition and
providing native operation system access to the stored objects.
